# Changelog

## 0.0.1

* First prototype version with a standard deduction variable

### 0.3.0

* Add Lifeline benefit

#### 0.3.1

* Add automated tests

### 0.4.0

* Broke down TANF eligibility into demographic and financial variables, with financial separated by current enrollment in program
* Specified demographic TANF eligibility per IL rules

### 0.5.0

* Added Medicaid Tests + Income Threshold Formula for California 

### 0.6.0

* Added Alternative Minimum Tax (AMT) income and liability logic
* Added development tools for auto-generating unit tests for Tax-Calculator functions

## 0.7.0

* Added Gains Tax (capital gains treatment) logic and parameters

### 0.8.0

* Added minimum benefit logic for SNAP

### 0.9.0

* Added Social Security taxation logic

### 0.10.0

* Added income-to-SMI variable, parameters and tests

